@@ -26,6 +26,7 @@ module Rake
       @no_native = false
       @config_includes = []
       @ruby_versions_per_platform = {}
+      @make = nil
     end
 
     def cross_platform
@@ -260,7 +261,7 @@ Java extension should be preferred.
           end
           spec.required_ruby_version = [
             ">= #{ruby_api_version(sorted_ruby_versions.first)}",
-            "< #{ruby_api_version(sorted_ruby_versions.last).succ}"
+            "< #{ruby_api_version(sorted_ruby_versions.last).succ}.dev"
           ]
 
           # clear the extensions defined in the specs
